package com.syjy.calculate.repository.repositoryImpl;

import com.syjy.calculate.entity.CalculationFormula;
import com.syjy.calculate.repository.CalculationFormulaRepository;
import lombok.extern.slf4j.Slf4j;
import org.springframework.dao.DataAccessException;
import org.springframework.jdbc.core.BeanPropertyRowMapper;
import org.springframework.jdbc.core.JdbcTemplate;
import org.springframework.jdbc.core.ResultSetExtractor;
import org.springframework.stereotype.Service;
import org.springframework.util.ResourceUtils;
import javax.annotation.Resource;
import java.io.*;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.List;

@Service
@Slf4j
public class CalculationFormulaRepositoryImpl implements CalculationFormulaRepository {

    @Resource
    public JdbcTemplate jdbcTemplate;

    @Override
    public void createTable() {
        // 判断表是否存在
        String checkSql = "SHOW TABLES LIKE 't_calculation_formula'";
        Boolean created = jdbcTemplate.query(checkSql, null, null, new ResultSetExtractor<Boolean>() {
            @Override
            public Boolean extractData(ResultSet rs) throws SQLException, DataAccessException {
                return rs.next();
            }
        });

        try {

            // 如果表存在，删除表
            if (created) {
                String dropSql = "DROP table t_calculation_formula";
                jdbcTemplate.execute(dropSql);
            }
            // 创建表
            String createSql = "create table t_calculation_formula ( ID int(0) not null auto_increment primary key, TYPE varchar(50) , `ORDER` int(0), FORMULA varchar(255) not null , PROVINCE_ENUM varchar(10), STATE varchar(10), CREATE_TIME datetime(0), CREATOR varchar(50), LAST_MODIFIER varchar(50), LAST_MODIFY_TIME datetime(0));";

            jdbcTemplate.execute(createSql);
            // 获取sql文件
            File sqlFile = ResourceUtils.getFile("classpath:sql/test.sql");
            // 读取文件
            FileReader fileReader = new FileReader(sqlFile);
            BufferedReader reader = new BufferedReader(fileReader);
            String s;
            StringBuilder builder = new StringBuilder();
            while ((s = reader.readLine()) != null) {
                builder.append(s);
            }
            jdbcTemplate.execute(builder.toString());
        } catch (DataAccessException e) {
            e.printStackTrace();
            log.info("删除/创建表错误：" + e.toString());
        } catch (FileNotFoundException e) {
            throw new RuntimeException(e);
        } catch (IOException e) {
            throw new RuntimeException(e);
        }
    }

    @Override
    public List<CalculationFormula> findByTypeAndProvince(String type,String provinceEnum) {
        provinceEnum = "%"+provinceEnum+";%";
        String sql = "SELECT * from t_calculation_formula where TYPE = ? and PROVINCE_ENUM like ?  ";

        List<CalculationFormula> calculationFormulaList = null;
        try {
            calculationFormulaList = jdbcTemplate.query(sql, new BeanPropertyRowMapper<>(CalculationFormula.class), type ,provinceEnum);
        } catch (DataAccessException e) {
            e.printStackTrace();
        }

        return calculationFormulaList;
    }

}
